/* BmpSupport.c generated by valac 0.40.4, the Vala compiler
 * generated from BmpSupport.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gphoto2/gphoto2-file.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define TYPE_PHOTO_FILE_FORMAT_PROPERTIES (photo_file_format_properties_get_type ())
#define PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties))
#define PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define PHOTO_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))

typedef struct _PhotoFileFormatProperties PhotoFileFormatProperties;
typedef struct _PhotoFileFormatPropertiesClass PhotoFileFormatPropertiesClass;
typedef struct _PhotoFileFormatPropertiesPrivate PhotoFileFormatPropertiesPrivate;

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define TYPE_PHOTO_FILE_FORMAT_FLAGS (photo_file_format_flags_get_type ())

#define PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES (photos_bmp_file_format_properties_get_type ())
#define PHOTOS_BMP_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties))
#define PHOTOS_BMP_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatPropertiesClass))
#define PHOTOS_IS_BMP_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES))
#define PHOTOS_IS_BMP_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES))
#define PHOTOS_BMP_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatPropertiesClass))

typedef struct _PhotosBmpFileFormatProperties PhotosBmpFileFormatProperties;
typedef struct _PhotosBmpFileFormatPropertiesClass PhotosBmpFileFormatPropertiesClass;
typedef struct _PhotosBmpFileFormatPropertiesPrivate PhotosBmpFileFormatPropertiesPrivate;
#define _photo_file_format_properties_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_properties_unref (var), NULL)))

#define TYPE_PHOTO_FILE_SNIFFER (photo_file_sniffer_get_type ())
#define PHOTO_FILE_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer))
#define PHOTO_FILE_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSnifferClass))
#define IS_PHOTO_FILE_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_SNIFFER))
#define IS_PHOTO_FILE_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_SNIFFER))
#define PHOTO_FILE_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSnifferClass))

typedef struct _PhotoFileSniffer PhotoFileSniffer;
typedef struct _PhotoFileSnifferClass PhotoFileSnifferClass;
typedef struct _PhotoFileSnifferPrivate PhotoFileSnifferPrivate;

#define TYPE_DETECTED_PHOTO_INFORMATION (detected_photo_information_get_type ())
#define DETECTED_PHOTO_INFORMATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformation))
#define DETECTED_PHOTO_INFORMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformationClass))
#define IS_DETECTED_PHOTO_INFORMATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DETECTED_PHOTO_INFORMATION))
#define IS_DETECTED_PHOTO_INFORMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DETECTED_PHOTO_INFORMATION))
#define DETECTED_PHOTO_INFORMATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformationClass))

typedef struct _DetectedPhotoInformation DetectedPhotoInformation;
typedef struct _DetectedPhotoInformationClass DetectedPhotoInformationClass;

#define PHOTO_FILE_SNIFFER_TYPE_OPTIONS (photo_file_sniffer_options_get_type ())

#define TYPE_GDK_SNIFFER (gdk_sniffer_get_type ())
#define GDK_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GDK_SNIFFER, GdkSniffer))
#define GDK_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GDK_SNIFFER, GdkSnifferClass))
#define IS_GDK_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GDK_SNIFFER))
#define IS_GDK_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GDK_SNIFFER))
#define GDK_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GDK_SNIFFER, GdkSnifferClass))

typedef struct _GdkSniffer GdkSniffer;
typedef struct _GdkSnifferClass GdkSnifferClass;
typedef struct _GdkSnifferPrivate GdkSnifferPrivate;

#define PHOTOS_TYPE_BMP_SNIFFER (photos_bmp_sniffer_get_type ())
#define PHOTOS_BMP_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_BMP_SNIFFER, PhotosBmpSniffer))
#define PHOTOS_BMP_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_BMP_SNIFFER, PhotosBmpSnifferClass))
#define PHOTOS_IS_BMP_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_BMP_SNIFFER))
#define PHOTOS_IS_BMP_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_BMP_SNIFFER))
#define PHOTOS_BMP_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_BMP_SNIFFER, PhotosBmpSnifferClass))

typedef struct _PhotosBmpSniffer PhotosBmpSniffer;
typedef struct _PhotosBmpSnifferClass PhotosBmpSnifferClass;
typedef struct _PhotosBmpSnifferPrivate PhotosBmpSnifferPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _detected_photo_information_unref0(var) ((var == NULL) ? NULL : (var = (detected_photo_information_unref (var), NULL)))
typedef struct _DetectedPhotoInformationPrivate DetectedPhotoInformationPrivate;

#define TYPE_MEDIA_METADATA (media_metadata_get_type ())
#define MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_METADATA, MediaMetadata))
#define MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_METADATA, MediaMetadataClass))
#define IS_MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_METADATA))
#define IS_MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_METADATA))
#define MEDIA_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_METADATA, MediaMetadataClass))

typedef struct _MediaMetadata MediaMetadata;
typedef struct _MediaMetadataClass MediaMetadataClass;

#define TYPE_PHOTO_METADATA (photo_metadata_get_type ())
#define PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_METADATA, PhotoMetadata))
#define PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_METADATA, PhotoMetadataClass))
#define IS_PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_METADATA))
#define IS_PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_METADATA))
#define PHOTO_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_METADATA, PhotoMetadataClass))

typedef struct _PhotoMetadata PhotoMetadata;
typedef struct _PhotoMetadataClass PhotoMetadataClass;

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;

#define TYPE_PHOTO_FILE_ADAPTER (photo_file_adapter_get_type ())
#define PHOTO_FILE_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter))
#define PHOTO_FILE_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapterClass))
#define IS_PHOTO_FILE_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_ADAPTER))
#define IS_PHOTO_FILE_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_ADAPTER))
#define PHOTO_FILE_ADAPTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapterClass))

typedef struct _PhotoFileAdapter PhotoFileAdapter;
typedef struct _PhotoFileAdapterClass PhotoFileAdapterClass;
typedef struct _PhotoFileAdapterPrivate PhotoFileAdapterPrivate;

#define TYPE_PHOTO_FILE_READER (photo_file_reader_get_type ())
#define PHOTO_FILE_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_READER, PhotoFileReader))
#define PHOTO_FILE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_READER, PhotoFileReaderClass))
#define IS_PHOTO_FILE_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_READER))
#define IS_PHOTO_FILE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_READER))
#define PHOTO_FILE_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_READER, PhotoFileReaderClass))

typedef struct _PhotoFileReader PhotoFileReader;
typedef struct _PhotoFileReaderClass PhotoFileReaderClass;
typedef struct _PhotoFileReaderPrivate PhotoFileReaderPrivate;

#define TYPE_GDK_READER (gdk_reader_get_type ())
#define GDK_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GDK_READER, GdkReader))
#define GDK_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GDK_READER, GdkReaderClass))
#define IS_GDK_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GDK_READER))
#define IS_GDK_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GDK_READER))
#define GDK_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GDK_READER, GdkReaderClass))

typedef struct _GdkReader GdkReader;
typedef struct _GdkReaderClass GdkReaderClass;
typedef struct _GdkReaderPrivate GdkReaderPrivate;

#define PHOTOS_TYPE_BMP_READER (photos_bmp_reader_get_type ())
#define PHOTOS_BMP_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_BMP_READER, PhotosBmpReader))
#define PHOTOS_BMP_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_BMP_READER, PhotosBmpReaderClass))
#define PHOTOS_IS_BMP_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_BMP_READER))
#define PHOTOS_IS_BMP_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_BMP_READER))
#define PHOTOS_BMP_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_BMP_READER, PhotosBmpReaderClass))

typedef struct _PhotosBmpReader PhotosBmpReader;
typedef struct _PhotosBmpReaderClass PhotosBmpReaderClass;
typedef struct _PhotosBmpReaderPrivate PhotosBmpReaderPrivate;

#define TYPE_SCALE_CONSTRAINT (scale_constraint_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_PHOTO_FILE_WRITER (photo_file_writer_get_type ())
#define PHOTO_FILE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_WRITER, PhotoFileWriter))
#define PHOTO_FILE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_WRITER, PhotoFileWriterClass))
#define IS_PHOTO_FILE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_WRITER))
#define IS_PHOTO_FILE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_WRITER))
#define PHOTO_FILE_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_WRITER, PhotoFileWriterClass))

typedef struct _PhotoFileWriter PhotoFileWriter;
typedef struct _PhotoFileWriterClass PhotoFileWriterClass;
typedef struct _PhotoFileWriterPrivate PhotoFileWriterPrivate;

#define JPEG_TYPE_QUALITY (jpeg_quality_get_type ())

#define PHOTOS_TYPE_BMP_WRITER (photos_bmp_writer_get_type ())
#define PHOTOS_BMP_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_BMP_WRITER, PhotosBmpWriter))
#define PHOTOS_BMP_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_BMP_WRITER, PhotosBmpWriterClass))
#define PHOTOS_IS_BMP_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_BMP_WRITER))
#define PHOTOS_IS_BMP_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_BMP_WRITER))
#define PHOTOS_BMP_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_BMP_WRITER, PhotosBmpWriterClass))

typedef struct _PhotosBmpWriter PhotosBmpWriter;
typedef struct _PhotosBmpWriterClass PhotosBmpWriterClass;
typedef struct _PhotosBmpWriterPrivate PhotosBmpWriterPrivate;

#define TYPE_PHOTO_FILE_METADATA_WRITER (photo_file_metadata_writer_get_type ())
#define PHOTO_FILE_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriter))
#define PHOTO_FILE_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriterClass))
#define IS_PHOTO_FILE_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_METADATA_WRITER))
#define IS_PHOTO_FILE_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_METADATA_WRITER))
#define PHOTO_FILE_METADATA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriterClass))

typedef struct _PhotoFileMetadataWriter PhotoFileMetadataWriter;
typedef struct _PhotoFileMetadataWriterClass PhotoFileMetadataWriterClass;
typedef struct _PhotoFileMetadataWriterPrivate PhotoFileMetadataWriterPrivate;

#define PHOTOS_TYPE_BMP_METADATA_WRITER (photos_bmp_metadata_writer_get_type ())
#define PHOTOS_BMP_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_BMP_METADATA_WRITER, PhotosBmpMetadataWriter))
#define PHOTOS_BMP_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_BMP_METADATA_WRITER, PhotosBmpMetadataWriterClass))
#define PHOTOS_IS_BMP_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_BMP_METADATA_WRITER))
#define PHOTOS_IS_BMP_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_BMP_METADATA_WRITER))
#define PHOTOS_BMP_METADATA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_BMP_METADATA_WRITER, PhotosBmpMetadataWriterClass))

typedef struct _PhotosBmpMetadataWriter PhotosBmpMetadataWriter;
typedef struct _PhotosBmpMetadataWriterClass PhotosBmpMetadataWriterClass;
typedef struct _PhotosBmpMetadataWriterPrivate PhotosBmpMetadataWriterPrivate;

#define TYPE_PHOTO_FILE_FORMAT_DRIVER (photo_file_format_driver_get_type ())
#define PHOTO_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriver))
#define PHOTO_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriverClass))
#define IS_PHOTO_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER))
#define IS_PHOTO_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_DRIVER))
#define PHOTO_FILE_FORMAT_DRIVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriverClass))

typedef struct _PhotoFileFormatDriver PhotoFileFormatDriver;
typedef struct _PhotoFileFormatDriverClass PhotoFileFormatDriverClass;
typedef struct _PhotoFileFormatDriverPrivate PhotoFileFormatDriverPrivate;

#define PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER (photos_bmp_file_format_driver_get_type ())
#define PHOTOS_BMP_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver))
#define PHOTOS_BMP_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriverClass))
#define PHOTOS_IS_BMP_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER))
#define PHOTOS_IS_BMP_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER))
#define PHOTOS_BMP_FILE_FORMAT_DRIVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriverClass))

typedef struct _PhotosBmpFileFormatDriver PhotosBmpFileFormatDriver;
typedef struct _PhotosBmpFileFormatDriverClass PhotosBmpFileFormatDriverClass;
typedef struct _PhotosBmpFileFormatDriverPrivate PhotosBmpFileFormatDriverPrivate;
#define _photo_file_format_driver_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_driver_unref (var), NULL)))

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

typedef enum  {
	PHOTO_FILE_FORMAT_FLAGS_NONE = 0x00000000
} PhotoFileFormatFlags;

struct _PhotoFileFormatProperties {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileFormatPropertiesPrivate * priv;
};

struct _PhotoFileFormatPropertiesClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileFormatProperties *self);
	PhotoFileFormat (*get_file_format) (PhotoFileFormatProperties* self);
	PhotoFileFormatFlags (*get_flags) (PhotoFileFormatProperties* self);
	gboolean (*is_recognized_extension) (PhotoFileFormatProperties* self, const gchar* ext);
	gchar* (*get_default_extension) (PhotoFileFormatProperties* self);
	gchar** (*get_known_extensions) (PhotoFileFormatProperties* self, int* result_length1);
	gchar* (*get_default_mime_type) (PhotoFileFormatProperties* self);
	gchar** (*get_mime_types) (PhotoFileFormatProperties* self, int* result_length1);
	gchar* (*get_user_visible_name) (PhotoFileFormatProperties* self);
};

struct _PhotosBmpFileFormatProperties {
	PhotoFileFormatProperties parent_instance;
	PhotosBmpFileFormatPropertiesPrivate * priv;
};

struct _PhotosBmpFileFormatPropertiesClass {
	PhotoFileFormatPropertiesClass parent_class;
};

typedef enum  {
	PHOTO_FILE_SNIFFER_OPTIONS_GET_ALL = 0x00000000,
	PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5 = 0x00000001
} PhotoFileSnifferOptions;

struct _PhotoFileSniffer {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileSnifferPrivate * priv;
	GFile* file;
	PhotoFileSnifferOptions options;
	gboolean calc_md5;
};

struct _PhotoFileSnifferClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileSniffer *self);
	DetectedPhotoInformation* (*sniff) (PhotoFileSniffer* self, gboolean* is_corrupted, GError** error);
};

struct _GdkSniffer {
	PhotoFileSniffer parent_instance;
	GdkSnifferPrivate * priv;
};

struct _GdkSnifferClass {
	PhotoFileSnifferClass parent_class;
};

struct _PhotosBmpSniffer {
	GdkSniffer parent_instance;
	PhotosBmpSnifferPrivate * priv;
};

struct _PhotosBmpSnifferClass {
	GdkSnifferClass parent_class;
};

struct _Dimensions {
	gint width;
	gint height;
};

struct _DetectedPhotoInformation {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DetectedPhotoInformationPrivate * priv;
	PhotoFileFormat file_format;
	PhotoMetadata* metadata;
	gchar* md5;
	gchar* exif_md5;
	gchar* thumbnail_md5;
	gchar* format_name;
	Dimensions image_dim;
	GdkColorspace colorspace;
	gint channels;
	gint bits_per_channel;
};

struct _DetectedPhotoInformationClass {
	GTypeClass parent_class;
	void (*finalize) (DetectedPhotoInformation *self);
};

struct _PhotoFileAdapter {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileAdapterPrivate * priv;
};

struct _PhotoFileAdapterClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileAdapter *self);
};

struct _PhotoFileReader {
	PhotoFileAdapter parent_instance;
	PhotoFileReaderPrivate * priv;
};

struct _PhotoFileReaderClass {
	PhotoFileAdapterClass parent_class;
	PhotoMetadata* (*read_metadata) (PhotoFileReader* self, GError** error);
	GdkPixbuf* (*unscaled_read) (PhotoFileReader* self, GError** error);
	GdkPixbuf* (*scaled_read) (PhotoFileReader* self, Dimensions* full, Dimensions* scaled, GError** error);
};

struct _GdkReader {
	PhotoFileReader parent_instance;
	GdkReaderPrivate * priv;
};

struct _GdkReaderClass {
	PhotoFileReaderClass parent_class;
};

struct _PhotosBmpReader {
	GdkReader parent_instance;
	PhotosBmpReaderPrivate * priv;
};

struct _PhotosBmpReaderClass {
	GdkReaderClass parent_class;
};

typedef enum  {
	SCALE_CONSTRAINT_ORIGINAL,
	SCALE_CONSTRAINT_DIMENSIONS,
	SCALE_CONSTRAINT_WIDTH,
	SCALE_CONSTRAINT_HEIGHT,
	SCALE_CONSTRAINT_FILL_VIEWPORT
} ScaleConstraint;

typedef enum  {
	JPEG_QUALITY_LOW = 50,
	JPEG_QUALITY_MEDIUM = 75,
	JPEG_QUALITY_HIGH = 90,
	JPEG_QUALITY_MAXIMUM = 100
} JpegQuality;

struct _PhotoFileWriter {
	PhotoFileAdapter parent_instance;
	PhotoFileWriterPrivate * priv;
};

struct _PhotoFileWriterClass {
	PhotoFileAdapterClass parent_class;
	void (*write) (PhotoFileWriter* self, GdkPixbuf* pixbuf, JpegQuality quality, GError** error);
};

struct _PhotosBmpWriter {
	PhotoFileWriter parent_instance;
	PhotosBmpWriterPrivate * priv;
};

struct _PhotosBmpWriterClass {
	PhotoFileWriterClass parent_class;
};

struct _PhotoFileMetadataWriter {
	PhotoFileAdapter parent_instance;
	PhotoFileMetadataWriterPrivate * priv;
};

struct _PhotoFileMetadataWriterClass {
	PhotoFileAdapterClass parent_class;
	void (*write_metadata) (PhotoFileMetadataWriter* self, PhotoMetadata* metadata, GError** error);
};

struct _PhotosBmpMetadataWriter {
	PhotoFileMetadataWriter parent_instance;
	PhotosBmpMetadataWriterPrivate * priv;
};

struct _PhotosBmpMetadataWriterClass {
	PhotoFileMetadataWriterClass parent_class;
};

struct _PhotoFileFormatDriver {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileFormatDriverPrivate * priv;
};

struct _PhotoFileFormatDriverClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileFormatDriver *self);
	PhotoFileFormatProperties* (*get_properties) (PhotoFileFormatDriver* self);
	PhotoFileReader* (*create_reader) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoMetadata* (*create_metadata) (PhotoFileFormatDriver* self);
	gboolean (*can_write_image) (PhotoFileFormatDriver* self);
	gboolean (*can_write_metadata) (PhotoFileFormatDriver* self);
	PhotoFileWriter* (*create_writer) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoFileMetadataWriter* (*create_metadata_writer) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoFileSniffer* (*create_sniffer) (PhotoFileFormatDriver* self, GFile* file, PhotoFileSnifferOptions options);
};

struct _PhotosBmpFileFormatDriver {
	PhotoFileFormatDriver parent_instance;
	PhotosBmpFileFormatDriverPrivate * priv;
};

struct _PhotosBmpFileFormatDriverClass {
	PhotoFileFormatDriverClass parent_class;
};


static gpointer photos_bmp_file_format_properties_parent_class = NULL;
static gchar** photos_bmp_file_format_properties_KNOWN_EXTENSIONS;
static gint photos_bmp_file_format_properties_KNOWN_EXTENSIONS_length1;
static gchar** photos_bmp_file_format_properties_KNOWN_EXTENSIONS = NULL;
static gint photos_bmp_file_format_properties_KNOWN_EXTENSIONS_length1 = 0;
static gint _photos_bmp_file_format_properties_KNOWN_EXTENSIONS_size_ = 0;
static gchar** photos_bmp_file_format_properties_KNOWN_MIME_TYPES;
static gint photos_bmp_file_format_properties_KNOWN_MIME_TYPES_length1;
static gchar** photos_bmp_file_format_properties_KNOWN_MIME_TYPES = NULL;
static gint photos_bmp_file_format_properties_KNOWN_MIME_TYPES_length1 = 0;
static gint _photos_bmp_file_format_properties_KNOWN_MIME_TYPES_size_ = 0;
static PhotosBmpFileFormatProperties* photos_bmp_file_format_properties_instance;
static PhotosBmpFileFormatProperties* photos_bmp_file_format_properties_instance = NULL;
static gpointer photos_bmp_sniffer_parent_class = NULL;
static gpointer photos_bmp_reader_parent_class = NULL;
static gpointer photos_bmp_writer_parent_class = NULL;
static gpointer photos_bmp_metadata_writer_parent_class = NULL;
static gpointer photos_bmp_file_format_driver_parent_class = NULL;
static PhotosBmpFileFormatDriver* photos_bmp_file_format_driver_instance;
static PhotosBmpFileFormatDriver* photos_bmp_file_format_driver_instance = NULL;

gpointer photo_file_format_properties_ref (gpointer instance);
void photo_file_format_properties_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_properties (const gchar* name,
                                                     const gchar* nick,
                                                     const gchar* blurb,
                                                     GType object_type,
                                                     GParamFlags flags);
void value_set_photo_file_format_properties (GValue* value,
                                             gpointer v_object);
void value_take_photo_file_format_properties (GValue* value,
                                              gpointer v_object);
gpointer value_get_photo_file_format_properties (const GValue* value);
GType photo_file_format_properties_get_type (void) G_GNUC_CONST;
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType photo_file_format_flags_get_type (void) G_GNUC_CONST;
GType photos_bmp_file_format_properties_get_type (void) G_GNUC_CONST;
void photos_bmp_file_format_properties_init (void);
PhotosBmpFileFormatProperties* photos_bmp_file_format_properties_new (void);
PhotosBmpFileFormatProperties* photos_bmp_file_format_properties_construct (GType object_type);
PhotosBmpFileFormatProperties* photos_bmp_file_format_properties_get_instance (void);
static PhotoFileFormat photos_bmp_file_format_properties_real_get_file_format (PhotoFileFormatProperties* base);
static PhotoFileFormatFlags photos_bmp_file_format_properties_real_get_flags (PhotoFileFormatProperties* base);
static gchar* photos_bmp_file_format_properties_real_get_user_visible_name (PhotoFileFormatProperties* base);
static gchar* photos_bmp_file_format_properties_real_get_default_extension (PhotoFileFormatProperties* base);
static gchar** photos_bmp_file_format_properties_real_get_known_extensions (PhotoFileFormatProperties* base,
                                                                     int* result_length1);
static gchar** _vala_array_dup8 (gchar** self,
                          int length);
static gchar* photos_bmp_file_format_properties_real_get_default_mime_type (PhotoFileFormatProperties* base);
static gchar** photos_bmp_file_format_properties_real_get_mime_types (PhotoFileFormatProperties* base,
                                                               int* result_length1);
static gchar** _vala_array_dup9 (gchar** self,
                          int length);
PhotoFileFormatProperties* photo_file_format_properties_construct (GType object_type);
static void photos_bmp_file_format_properties_finalize (PhotoFileFormatProperties * obj);
gpointer photo_file_sniffer_ref (gpointer instance);
void photo_file_sniffer_unref (gpointer instance);
GParamSpec* param_spec_photo_file_sniffer (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
void value_set_photo_file_sniffer (GValue* value,
                                   gpointer v_object);
void value_take_photo_file_sniffer (GValue* value,
                                    gpointer v_object);
gpointer value_get_photo_file_sniffer (const GValue* value);
GType photo_file_sniffer_get_type (void) G_GNUC_CONST;
gpointer detected_photo_information_ref (gpointer instance);
void detected_photo_information_unref (gpointer instance);
GParamSpec* param_spec_detected_photo_information (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags);
void value_set_detected_photo_information (GValue* value,
                                           gpointer v_object);
void value_take_detected_photo_information (GValue* value,
                                            gpointer v_object);
gpointer value_get_detected_photo_information (const GValue* value);
GType detected_photo_information_get_type (void) G_GNUC_CONST;
GType photo_file_sniffer_options_get_type (void) G_GNUC_CONST;
GType gdk_sniffer_get_type (void) G_GNUC_CONST;
GType photos_bmp_sniffer_get_type (void) G_GNUC_CONST;
PhotosBmpSniffer* photos_bmp_sniffer_new (GFile* file,
                                          PhotoFileSnifferOptions options);
PhotosBmpSniffer* photos_bmp_sniffer_construct (GType object_type,
                                                GFile* file,
                                                PhotoFileSnifferOptions options);
GdkSniffer* gdk_sniffer_construct (GType object_type,
                                   GFile* file,
                                   PhotoFileSnifferOptions options);
static gboolean photos_bmp_sniffer_is_bmp_file (GFile* file,
                                         GError** error);
static DetectedPhotoInformation* photos_bmp_sniffer_real_sniff (PhotoFileSniffer* base,
                                                         gboolean* is_corrupted,
                                                         GError** error);
DetectedPhotoInformation* photo_file_sniffer_sniff (PhotoFileSniffer* self,
                                                    gboolean* is_corrupted,
                                                    GError** error);
gpointer media_metadata_ref (gpointer instance);
void media_metadata_unref (gpointer instance);
GParamSpec* param_spec_media_metadata (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags);
void value_set_media_metadata (GValue* value,
                               gpointer v_object);
void value_take_media_metadata (GValue* value,
                                gpointer v_object);
gpointer value_get_media_metadata (const GValue* value);
GType media_metadata_get_type (void) G_GNUC_CONST;
GType photo_metadata_get_type (void) G_GNUC_CONST;
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
gpointer photo_file_adapter_ref (gpointer instance);
void photo_file_adapter_unref (gpointer instance);
GParamSpec* param_spec_photo_file_adapter (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
void value_set_photo_file_adapter (GValue* value,
                                   gpointer v_object);
void value_take_photo_file_adapter (GValue* value,
                                    gpointer v_object);
gpointer value_get_photo_file_adapter (const GValue* value);
GType photo_file_adapter_get_type (void) G_GNUC_CONST;
GType photo_file_reader_get_type (void) G_GNUC_CONST;
GType gdk_reader_get_type (void) G_GNUC_CONST;
GType photos_bmp_reader_get_type (void) G_GNUC_CONST;
PhotosBmpReader* photos_bmp_reader_new (const gchar* filepath);
PhotosBmpReader* photos_bmp_reader_construct (GType object_type,
                                              const gchar* filepath);
GdkReader* gdk_reader_construct (GType object_type,
                                 const gchar* filepath,
                                 PhotoFileFormat file_format);
static GdkPixbuf* photos_bmp_reader_real_scaled_read (PhotoFileReader* base,
                                               Dimensions* full,
                                               Dimensions* scaled,
                                               GError** error);
GType scale_constraint_get_type (void) G_GNUC_CONST;
void dimensions_get_scaled_by_constraint (Dimensions *self,
                                          gint scale,
                                          ScaleConstraint constraint,
                                          Dimensions* result);
gchar* photo_file_adapter_get_filepath (PhotoFileAdapter* self);
GType photo_file_writer_get_type (void) G_GNUC_CONST;
GType jpeg_quality_get_type (void) G_GNUC_CONST;
GType photos_bmp_writer_get_type (void) G_GNUC_CONST;
PhotosBmpWriter* photos_bmp_writer_new (const gchar* filepath);
PhotosBmpWriter* photos_bmp_writer_construct (GType object_type,
                                              const gchar* filepath);
PhotoFileWriter* photo_file_writer_construct (GType object_type,
                                              const gchar* filepath,
                                              PhotoFileFormat file_format);
static void photos_bmp_writer_real_write (PhotoFileWriter* base,
                                   GdkPixbuf* pixbuf,
                                   JpegQuality quality,
                                   GError** error);
GType photo_file_metadata_writer_get_type (void) G_GNUC_CONST;
GType photos_bmp_metadata_writer_get_type (void) G_GNUC_CONST;
PhotosBmpMetadataWriter* photos_bmp_metadata_writer_new (const gchar* filepath);
PhotosBmpMetadataWriter* photos_bmp_metadata_writer_construct (GType object_type,
                                                               const gchar* filepath);
PhotoFileMetadataWriter* photo_file_metadata_writer_construct (GType object_type,
                                                               const gchar* filepath,
                                                               PhotoFileFormat file_format);
static void photos_bmp_metadata_writer_real_write_metadata (PhotoFileMetadataWriter* base,
                                                     PhotoMetadata* metadata,
                                                     GError** error);
gpointer photo_file_format_driver_ref (gpointer instance);
void photo_file_format_driver_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_driver (const gchar* name,
                                                 const gchar* nick,
                                                 const gchar* blurb,
                                                 GType object_type,
                                                 GParamFlags flags);
void value_set_photo_file_format_driver (GValue* value,
                                         gpointer v_object);
void value_take_photo_file_format_driver (GValue* value,
                                          gpointer v_object);
gpointer value_get_photo_file_format_driver (const GValue* value);
GType photo_file_format_driver_get_type (void) G_GNUC_CONST;
GType photos_bmp_file_format_driver_get_type (void) G_GNUC_CONST;
void photos_bmp_file_format_driver_init (void);
PhotosBmpFileFormatDriver* photos_bmp_file_format_driver_new (void);
PhotosBmpFileFormatDriver* photos_bmp_file_format_driver_construct (GType object_type);
PhotosBmpFileFormatDriver* photos_bmp_file_format_driver_get_instance (void);
static PhotoFileFormatProperties* photos_bmp_file_format_driver_real_get_properties (PhotoFileFormatDriver* base);
static PhotoFileReader* photos_bmp_file_format_driver_real_create_reader (PhotoFileFormatDriver* base,
                                                                   const gchar* filepath);
static gboolean photos_bmp_file_format_driver_real_can_write_image (PhotoFileFormatDriver* base);
static gboolean photos_bmp_file_format_driver_real_can_write_metadata (PhotoFileFormatDriver* base);
static PhotoFileWriter* photos_bmp_file_format_driver_real_create_writer (PhotoFileFormatDriver* base,
                                                                   const gchar* filepath);
static PhotoFileMetadataWriter* photos_bmp_file_format_driver_real_create_metadata_writer (PhotoFileFormatDriver* base,
                                                                                    const gchar* filepath);
static PhotoFileSniffer* photos_bmp_file_format_driver_real_create_sniffer (PhotoFileFormatDriver* base,
                                                                     GFile* file,
                                                                     PhotoFileSnifferOptions options);
static PhotoMetadata* photos_bmp_file_format_driver_real_create_metadata (PhotoFileFormatDriver* base);
PhotoMetadata* photo_metadata_new (void);
PhotoMetadata* photo_metadata_construct (GType object_type);
PhotoFileFormatDriver* photo_file_format_driver_construct (GType object_type);
static void photos_bmp_file_format_driver_finalize (PhotoFileFormatDriver * obj);

static const guint8 PHOTOS_BMP_SNIFFER_MAGIC_SEQUENCE[2] = {(guint8) 0x42, (guint8) 0x4D};

void
photos_bmp_file_format_properties_init (void)
{
	PhotosBmpFileFormatProperties* _tmp0_;
#line 16 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_properties_new ();
#line 16 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_photo_file_format_properties_unref0 (photos_bmp_file_format_properties_instance);
#line 16 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_properties_instance = _tmp0_;
#line 686 "BmpSupport.c"
}


static gpointer
_photo_file_format_properties_ref0 (gpointer self)
{
#line 20 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self ? photo_file_format_properties_ref (self) : NULL;
#line 695 "BmpSupport.c"
}


PhotosBmpFileFormatProperties*
photos_bmp_file_format_properties_get_instance (void)
{
	PhotosBmpFileFormatProperties* result = NULL;
	PhotosBmpFileFormatProperties* _tmp0_;
	PhotosBmpFileFormatProperties* _tmp1_;
#line 20 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_properties_instance;
#line 20 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = _photo_file_format_properties_ref0 (_tmp0_);
#line 20 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp1_;
#line 20 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 713 "BmpSupport.c"
}


static PhotoFileFormat
photos_bmp_file_format_properties_real_get_file_format (PhotoFileFormatProperties* base)
{
	PhotosBmpFileFormatProperties * self;
	PhotoFileFormat result = 0;
#line 23 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties);
#line 24 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = PHOTO_FILE_FORMAT_BMP;
#line 24 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 728 "BmpSupport.c"
}


static PhotoFileFormatFlags
photos_bmp_file_format_properties_real_get_flags (PhotoFileFormatProperties* base)
{
	PhotosBmpFileFormatProperties * self;
	PhotoFileFormatFlags result = 0;
#line 27 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties);
#line 28 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = PHOTO_FILE_FORMAT_FLAGS_NONE;
#line 28 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 743 "BmpSupport.c"
}


static gchar*
photos_bmp_file_format_properties_real_get_user_visible_name (PhotoFileFormatProperties* base)
{
	PhotosBmpFileFormatProperties * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 31 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties);
#line 32 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = g_strdup (_ ("BMP"));
#line 32 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp0_;
#line 32 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 761 "BmpSupport.c"
}


static gchar*
photos_bmp_file_format_properties_real_get_default_extension (PhotoFileFormatProperties* base)
{
	PhotosBmpFileFormatProperties * self;
	gchar* result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 35 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties);
#line 36 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_properties_KNOWN_EXTENSIONS;
#line 36 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0__length1 = photos_bmp_file_format_properties_KNOWN_EXTENSIONS_length1;
#line 36 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = _tmp0_[0];
#line 36 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 36 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp2_;
#line 36 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 788 "BmpSupport.c"
}


static gchar**
_vala_array_dup8 (gchar** self,
                  int length)
{
	gchar** result;
	int i;
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = g_new0 (gchar*, length + 1);
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	for (i = 0; i < length; i++) {
#line 802 "BmpSupport.c"
		gchar* _tmp0_;
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp0_ = g_strdup (self[i]);
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		result[i] = _tmp0_;
#line 808 "BmpSupport.c"
	}
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 812 "BmpSupport.c"
}


static gchar**
photos_bmp_file_format_properties_real_get_known_extensions (PhotoFileFormatProperties* base,
                                                             int* result_length1)
{
	PhotosBmpFileFormatProperties * self;
	gchar** result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gchar** _tmp2_;
	gint _tmp2__length1;
#line 39 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties);
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_properties_KNOWN_EXTENSIONS;
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0__length1 = photos_bmp_file_format_properties_KNOWN_EXTENSIONS_length1;
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup8 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1__length1 = _tmp0__length1;
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_ = _tmp1_;
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2__length1 = _tmp1__length1;
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (result_length1) {
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		*result_length1 = _tmp2__length1;
#line 846 "BmpSupport.c"
	}
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp2_;
#line 40 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 852 "BmpSupport.c"
}


static gchar*
photos_bmp_file_format_properties_real_get_default_mime_type (PhotoFileFormatProperties* base)
{
	PhotosBmpFileFormatProperties * self;
	gchar* result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 43 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties);
#line 44 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_properties_KNOWN_MIME_TYPES;
#line 44 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0__length1 = photos_bmp_file_format_properties_KNOWN_MIME_TYPES_length1;
#line 44 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = _tmp0_[0];
#line 44 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 44 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp2_;
#line 44 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 879 "BmpSupport.c"
}


static gchar**
_vala_array_dup9 (gchar** self,
                  int length)
{
	gchar** result;
	int i;
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = g_new0 (gchar*, length + 1);
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	for (i = 0; i < length; i++) {
#line 893 "BmpSupport.c"
		gchar* _tmp0_;
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp0_ = g_strdup (self[i]);
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		result[i] = _tmp0_;
#line 899 "BmpSupport.c"
	}
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 903 "BmpSupport.c"
}


static gchar**
photos_bmp_file_format_properties_real_get_mime_types (PhotoFileFormatProperties* base,
                                                       int* result_length1)
{
	PhotosBmpFileFormatProperties * self;
	gchar** result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gchar** _tmp2_;
	gint _tmp2__length1;
#line 47 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties);
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_properties_KNOWN_MIME_TYPES;
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0__length1 = photos_bmp_file_format_properties_KNOWN_MIME_TYPES_length1;
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup9 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1__length1 = _tmp0__length1;
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_ = _tmp1_;
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2__length1 = _tmp1__length1;
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (result_length1) {
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		*result_length1 = _tmp2__length1;
#line 937 "BmpSupport.c"
	}
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp2_;
#line 48 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 943 "BmpSupport.c"
}


PhotosBmpFileFormatProperties*
photos_bmp_file_format_properties_construct (GType object_type)
{
	PhotosBmpFileFormatProperties* self = NULL;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = (PhotosBmpFileFormatProperties*) photo_file_format_properties_construct (object_type);
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self;
#line 955 "BmpSupport.c"
}


PhotosBmpFileFormatProperties*
photos_bmp_file_format_properties_new (void)
{
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return photos_bmp_file_format_properties_construct (PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES);
#line 964 "BmpSupport.c"
}


static void
photos_bmp_file_format_properties_class_init (PhotosBmpFileFormatPropertiesClass * klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_properties_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->finalize = photos_bmp_file_format_properties_finalize;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_file_format = (PhotoFileFormat (*) (PhotoFileFormatProperties *)) photos_bmp_file_format_properties_real_get_file_format;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_flags = (PhotoFileFormatFlags (*) (PhotoFileFormatProperties *)) photos_bmp_file_format_properties_real_get_flags;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_user_visible_name = (gchar* (*) (PhotoFileFormatProperties *)) photos_bmp_file_format_properties_real_get_user_visible_name;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_default_extension = (gchar* (*) (PhotoFileFormatProperties *)) photos_bmp_file_format_properties_real_get_default_extension;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_known_extensions = (gchar** (*) (PhotoFileFormatProperties *, int*)) photos_bmp_file_format_properties_real_get_known_extensions;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_default_mime_type = (gchar* (*) (PhotoFileFormatProperties *)) photos_bmp_file_format_properties_real_get_default_mime_type;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_mime_types = (gchar** (*) (PhotoFileFormatProperties *, int*)) photos_bmp_file_format_properties_real_get_mime_types;
#line 10 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = g_strdup ("bmp");
#line 10 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = g_strdup ("dib");
#line 10 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 10 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_[0] = _tmp0_;
#line 10 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_[1] = _tmp1_;
#line 10 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_properties_KNOWN_EXTENSIONS = _tmp2_;
#line 10 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_properties_KNOWN_EXTENSIONS_length1 = 2;
#line 11 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp3_ = g_strdup (GP_MIME_BMP);
#line 11 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp4_ = g_new0 (gchar*, 1 + 1);
#line 11 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp4_[0] = _tmp3_;
#line 11 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_properties_KNOWN_MIME_TYPES = _tmp4_;
#line 11 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_properties_KNOWN_MIME_TYPES_length1 = 1;
#line 1018 "BmpSupport.c"
}


static void
photos_bmp_file_format_properties_instance_init (PhotosBmpFileFormatProperties * self)
{
}


static void
photos_bmp_file_format_properties_finalize (PhotoFileFormatProperties * obj)
{
	PhotosBmpFileFormatProperties * self;
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTOS_TYPE_BMP_FILE_FORMAT_PROPERTIES, PhotosBmpFileFormatProperties);
#line 9 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	PHOTO_FILE_FORMAT_PROPERTIES_CLASS (photos_bmp_file_format_properties_parent_class)->finalize (obj);
#line 1036 "BmpSupport.c"
}


GType
photos_bmp_file_format_properties_get_type (void)
{
	static volatile gsize photos_bmp_file_format_properties_type_id__volatile = 0;
	if (g_once_init_enter (&photos_bmp_file_format_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosBmpFileFormatPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_bmp_file_format_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosBmpFileFormatProperties), 0, (GInstanceInitFunc) photos_bmp_file_format_properties_instance_init, NULL };
		GType photos_bmp_file_format_properties_type_id;
		photos_bmp_file_format_properties_type_id = g_type_register_static (TYPE_PHOTO_FILE_FORMAT_PROPERTIES, "PhotosBmpFileFormatProperties", &g_define_type_info, 0);
		g_once_init_leave (&photos_bmp_file_format_properties_type_id__volatile, photos_bmp_file_format_properties_type_id);
	}
	return photos_bmp_file_format_properties_type_id__volatile;
}


PhotosBmpSniffer*
photos_bmp_sniffer_construct (GType object_type,
                              GFile* file,
                              PhotoFileSnifferOptions options)
{
	PhotosBmpSniffer* self = NULL;
#line 55 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 56 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = (PhotosBmpSniffer*) gdk_sniffer_construct (object_type, file, options);
#line 55 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self;
#line 1066 "BmpSupport.c"
}


PhotosBmpSniffer*
photos_bmp_sniffer_new (GFile* file,
                        PhotoFileSnifferOptions options)
{
#line 55 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return photos_bmp_sniffer_construct (PHOTOS_TYPE_BMP_SNIFFER, file, options);
#line 1076 "BmpSupport.c"
}


static gboolean
photos_bmp_sniffer_is_bmp_file (GFile* file,
                                GError** error)
{
	gboolean result = FALSE;
	GFileInputStream* instream = NULL;
	GFileInputStream* _tmp0_;
	guint8* file_lead_sequence = NULL;
	guint8* _tmp2_;
	gint file_lead_sequence_length1;
	gint _file_lead_sequence_size_;
	GFileInputStream* _tmp3_;
	guint8* _tmp4_;
	gint _tmp4__length1;
	GError * _inner_error_ = NULL;
#line 59 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 60 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = g_file_read (file, NULL, &_inner_error_);
#line 60 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	instream = _tmp0_;
#line 60 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1103 "BmpSupport.c"
		gboolean _tmp1_ = FALSE;
#line 60 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 60 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		return _tmp1_;
#line 1109 "BmpSupport.c"
	}
#line 62 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_ = g_new0 (guint8, G_N_ELEMENTS (PHOTOS_BMP_SNIFFER_MAGIC_SEQUENCE));
#line 62 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	file_lead_sequence = _tmp2_;
#line 62 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	file_lead_sequence_length1 = G_N_ELEMENTS (PHOTOS_BMP_SNIFFER_MAGIC_SEQUENCE);
#line 62 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_file_lead_sequence_size_ = file_lead_sequence_length1;
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp3_ = instream;
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp4_ = file_lead_sequence;
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp4__length1 = file_lead_sequence_length1;
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_input_stream_read (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, g_input_stream_get_type (), GInputStream), _tmp4_, (gsize) _tmp4__length1, NULL, &_inner_error_);
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1129 "BmpSupport.c"
		gboolean _tmp5_ = FALSE;
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		file_lead_sequence = (g_free (file_lead_sequence), NULL);
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_g_object_unref0 (instream);
#line 64 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		return _tmp5_;
#line 1139 "BmpSupport.c"
	}
	{
		gint i = 0;
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		i = 0;
#line 1145 "BmpSupport.c"
		{
			gboolean _tmp6_ = FALSE;
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			_tmp6_ = TRUE;
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			while (TRUE) {
#line 1152 "BmpSupport.c"
				gint _tmp8_;
				guint8* _tmp9_;
				gint _tmp9__length1;
				gint _tmp10_;
				guint8 _tmp11_;
				gint _tmp12_;
				guint8 _tmp13_;
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				if (!_tmp6_) {
#line 1162 "BmpSupport.c"
					gint _tmp7_;
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
					_tmp7_ = i;
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
					i = _tmp7_ + 1;
#line 1168 "BmpSupport.c"
				}
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				_tmp6_ = FALSE;
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				_tmp8_ = i;
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				if (!(_tmp8_ < G_N_ELEMENTS (PHOTOS_BMP_SNIFFER_MAGIC_SEQUENCE))) {
#line 66 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
					break;
#line 1178 "BmpSupport.c"
				}
#line 67 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				_tmp9_ = file_lead_sequence;
#line 67 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				_tmp9__length1 = file_lead_sequence_length1;
#line 67 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				_tmp10_ = i;
#line 67 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				_tmp11_ = _tmp9_[_tmp10_];
#line 67 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				_tmp12_ = i;
#line 67 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				_tmp13_ = PHOTOS_BMP_SNIFFER_MAGIC_SEQUENCE[_tmp12_];
#line 67 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
				if (_tmp11_ != _tmp13_) {
#line 68 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
					result = FALSE;
#line 68 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
					file_lead_sequence = (g_free (file_lead_sequence), NULL);
#line 68 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
					_g_object_unref0 (instream);
#line 68 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
					return result;
#line 1202 "BmpSupport.c"
				}
			}
		}
	}
#line 71 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = TRUE;
#line 71 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	file_lead_sequence = (g_free (file_lead_sequence), NULL);
#line 71 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_g_object_unref0 (instream);
#line 71 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1215 "BmpSupport.c"
}


static gpointer
_detected_photo_information_ref0 (gpointer self)
{
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self ? detected_photo_information_ref (self) : NULL;
#line 1224 "BmpSupport.c"
}


static DetectedPhotoInformation*
photos_bmp_sniffer_real_sniff (PhotoFileSniffer* base,
                               gboolean* is_corrupted,
                               GError** error)
{
	PhotosBmpSniffer * self;
	gboolean _vala_is_corrupted = FALSE;
	DetectedPhotoInformation* result = NULL;
	gboolean _tmp0_ = FALSE;
	GFile* _tmp1_;
	DetectedPhotoInformation* detected = NULL;
	gboolean _tmp2_ = FALSE;
	DetectedPhotoInformation* _tmp3_;
	DetectedPhotoInformation* _tmp4_;
	DetectedPhotoInformation* _tmp5_ = NULL;
	DetectedPhotoInformation* _tmp6_;
	PhotoFileFormat _tmp7_;
	DetectedPhotoInformation* _tmp9_;
	GError * _inner_error_ = NULL;
#line 74 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_SNIFFER, PhotosBmpSniffer);
#line 76 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_vala_is_corrupted = FALSE;
#line 78 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer)->file;
#line 78 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_sniffer_is_bmp_file (_tmp1_, &_inner_error_);
#line 78 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 78 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 78 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		return NULL;
#line 1261 "BmpSupport.c"
	}
#line 78 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (!_tmp0_) {
#line 79 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		result = NULL;
#line 79 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		if (is_corrupted) {
#line 79 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			*is_corrupted = _vala_is_corrupted;
#line 1271 "BmpSupport.c"
		}
#line 79 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		return result;
#line 1275 "BmpSupport.c"
	}
#line 81 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp3_ = PHOTO_FILE_SNIFFER_CLASS (photos_bmp_sniffer_parent_class)->sniff (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_GDK_SNIFFER, GdkSniffer), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer), &_tmp2_, &_inner_error_);
#line 81 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_vala_is_corrupted = _tmp2_;
#line 81 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	detected = _tmp3_;
#line 81 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 81 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		return NULL;
#line 1289 "BmpSupport.c"
	}
#line 82 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp4_ = detected;
#line 82 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (_tmp4_ == NULL) {
#line 83 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		result = NULL;
#line 83 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_detected_photo_information_unref0 (detected);
#line 83 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		if (is_corrupted) {
#line 83 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			*is_corrupted = _vala_is_corrupted;
#line 1303 "BmpSupport.c"
		}
#line 83 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		return result;
#line 1307 "BmpSupport.c"
	}
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp6_ = detected;
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp7_ = _tmp6_->file_format;
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (_tmp7_ == PHOTO_FILE_FORMAT_BMP) {
#line 1315 "BmpSupport.c"
		DetectedPhotoInformation* _tmp8_;
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp8_ = detected;
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp5_ = _tmp8_;
#line 1321 "BmpSupport.c"
	} else {
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp5_ = NULL;
#line 1325 "BmpSupport.c"
	}
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp9_ = _detected_photo_information_ref0 (_tmp5_);
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp9_;
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_detected_photo_information_unref0 (detected);
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (is_corrupted) {
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		*is_corrupted = _vala_is_corrupted;
#line 1337 "BmpSupport.c"
	}
#line 85 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1341 "BmpSupport.c"
}


static void
photos_bmp_sniffer_class_init (PhotosBmpSnifferClass * klass)
{
#line 52 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_sniffer_parent_class = g_type_class_peek_parent (klass);
#line 52 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileSnifferClass *) klass)->sniff = (DetectedPhotoInformation* (*) (PhotoFileSniffer *, gboolean*, GError**)) photos_bmp_sniffer_real_sniff;
#line 1352 "BmpSupport.c"
}


static void
photos_bmp_sniffer_instance_init (PhotosBmpSniffer * self)
{
}


GType
photos_bmp_sniffer_get_type (void)
{
	static volatile gsize photos_bmp_sniffer_type_id__volatile = 0;
	if (g_once_init_enter (&photos_bmp_sniffer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosBmpSnifferClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_bmp_sniffer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosBmpSniffer), 0, (GInstanceInitFunc) photos_bmp_sniffer_instance_init, NULL };
		GType photos_bmp_sniffer_type_id;
		photos_bmp_sniffer_type_id = g_type_register_static (TYPE_GDK_SNIFFER, "PhotosBmpSniffer", &g_define_type_info, 0);
		g_once_init_leave (&photos_bmp_sniffer_type_id__volatile, photos_bmp_sniffer_type_id);
	}
	return photos_bmp_sniffer_type_id__volatile;
}


PhotosBmpReader*
photos_bmp_reader_construct (GType object_type,
                             const gchar* filepath)
{
	PhotosBmpReader* self = NULL;
#line 90 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 91 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = (PhotosBmpReader*) gdk_reader_construct (object_type, filepath, PHOTO_FILE_FORMAT_BMP);
#line 90 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self;
#line 1387 "BmpSupport.c"
}


PhotosBmpReader*
photos_bmp_reader_new (const gchar* filepath)
{
#line 90 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return photos_bmp_reader_construct (PHOTOS_TYPE_BMP_READER, filepath);
#line 1396 "BmpSupport.c"
}


static GdkPixbuf*
photos_bmp_reader_real_scaled_read (PhotoFileReader* base,
                                    Dimensions* full,
                                    Dimensions* scaled,
                                    GError** error)
{
	PhotosBmpReader * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* _result_ = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	Dimensions _tmp2_;
	gint _tmp3_;
	GError * _inner_error_ = NULL;
#line 94 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_READER, PhotosBmpReader);
#line 94 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (full != NULL, NULL);
#line 94 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (scaled != NULL, NULL);
#line 95 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_result_ = NULL;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp2_ = *full;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp3_ = _tmp2_.width;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (_tmp3_ > 9999) {
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp1_ = TRUE;
#line 1430 "BmpSupport.c"
	} else {
		Dimensions _tmp4_;
		gint _tmp5_;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp4_ = *full;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp5_ = _tmp4_.height;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp1_ = _tmp5_ > 9999;
#line 1440 "BmpSupport.c"
	}
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (_tmp1_) {
#line 1444 "BmpSupport.c"
		gboolean _tmp6_ = FALSE;
		Dimensions _tmp7_;
		gint _tmp8_;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp7_ = *scaled;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp8_ = _tmp7_.width;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		if (_tmp8_ < 100) {
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			_tmp6_ = TRUE;
#line 1456 "BmpSupport.c"
		} else {
			Dimensions _tmp9_;
			gint _tmp10_;
#line 105 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			_tmp9_ = *scaled;
#line 105 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			_tmp10_ = _tmp9_.height;
#line 105 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			_tmp6_ = _tmp10_ < 100;
#line 1466 "BmpSupport.c"
		}
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp0_ = _tmp6_;
#line 1470 "BmpSupport.c"
	} else {
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp0_ = FALSE;
#line 1474 "BmpSupport.c"
	}
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (_tmp0_) {
#line 1478 "BmpSupport.c"
		Dimensions prefetch_dimensions = {0};
		Dimensions _tmp11_ = {0};
		GdkPixbuf* _tmp12_ = NULL;
		gchar* _tmp13_;
		gchar* _tmp14_;
		Dimensions _tmp15_;
		gint _tmp16_;
		Dimensions _tmp17_;
		gint _tmp18_;
		GdkPixbuf* _tmp19_;
		GdkPixbuf* _tmp20_;
		GdkPixbuf* _tmp21_;
		GdkPixbuf* _tmp22_;
		Dimensions _tmp23_;
		gint _tmp24_;
		Dimensions _tmp25_;
		gint _tmp26_;
		GdkPixbuf* _tmp27_;
#line 106 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		dimensions_get_scaled_by_constraint (full, 1000, SCALE_CONSTRAINT_DIMENSIONS, &_tmp11_);
#line 106 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		prefetch_dimensions = _tmp11_;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp13_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp14_ = _tmp13_;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp15_ = prefetch_dimensions;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp16_ = _tmp15_.width;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp17_ = prefetch_dimensions;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp18_ = _tmp17_.height;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp19_ = gdk_pixbuf_new_from_file_at_scale (_tmp14_, _tmp16_, _tmp18_, FALSE, &_inner_error_);
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp20_ = _tmp19_;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_g_free0 (_tmp14_);
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp12_ = _tmp20_;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			g_propagate_error (error, _inner_error_);
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			_g_object_unref0 (_result_);
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			return NULL;
#line 1529 "BmpSupport.c"
		}
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp21_ = _tmp12_;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp12_ = NULL;
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_g_object_unref0 (_result_);
#line 109 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_result_ = _tmp21_;
#line 112 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp22_ = _result_;
#line 112 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp23_ = *scaled;
#line 112 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp24_ = _tmp23_.width;
#line 112 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp25_ = *scaled;
#line 112 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp26_ = _tmp25_.height;
#line 112 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp27_ = gdk_pixbuf_scale_simple (_tmp22_, _tmp24_, _tmp26_, GDK_INTERP_HYPER);
#line 112 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_g_object_unref0 (_result_);
#line 112 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_result_ = _tmp27_;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_g_object_unref0 (_tmp12_);
#line 1557 "BmpSupport.c"
	} else {
		GdkPixbuf* _tmp28_ = NULL;
		gchar* _tmp29_;
		gchar* _tmp30_;
		Dimensions _tmp31_;
		gint _tmp32_;
		Dimensions _tmp33_;
		gint _tmp34_;
		GdkPixbuf* _tmp35_;
		GdkPixbuf* _tmp36_;
		GdkPixbuf* _tmp37_;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp29_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp30_ = _tmp29_;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp31_ = *scaled;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp32_ = _tmp31_.width;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp33_ = *scaled;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp34_ = _tmp33_.height;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp35_ = gdk_pixbuf_new_from_file_at_scale (_tmp30_, _tmp32_, _tmp34_, FALSE, &_inner_error_);
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp36_ = _tmp35_;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_g_free0 (_tmp30_);
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp28_ = _tmp36_;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			g_propagate_error (error, _inner_error_);
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			_g_object_unref0 (_result_);
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
			return NULL;
#line 1597 "BmpSupport.c"
		}
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp37_ = _tmp28_;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_tmp28_ = NULL;
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_g_object_unref0 (_result_);
#line 114 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_result_ = _tmp37_;
#line 104 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		_g_object_unref0 (_tmp28_);
#line 1609 "BmpSupport.c"
	}
#line 118 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _result_;
#line 118 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1615 "BmpSupport.c"
}


static void
photos_bmp_reader_class_init (PhotosBmpReaderClass * klass)
{
#line 89 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_reader_parent_class = g_type_class_peek_parent (klass);
#line 89 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileReaderClass *) klass)->scaled_read = (GdkPixbuf* (*) (PhotoFileReader *, Dimensions*, Dimensions*, GError**)) photos_bmp_reader_real_scaled_read;
#line 1626 "BmpSupport.c"
}


static void
photos_bmp_reader_instance_init (PhotosBmpReader * self)
{
}


GType
photos_bmp_reader_get_type (void)
{
	static volatile gsize photos_bmp_reader_type_id__volatile = 0;
	if (g_once_init_enter (&photos_bmp_reader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosBmpReaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_bmp_reader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosBmpReader), 0, (GInstanceInitFunc) photos_bmp_reader_instance_init, NULL };
		GType photos_bmp_reader_type_id;
		photos_bmp_reader_type_id = g_type_register_static (TYPE_GDK_READER, "PhotosBmpReader", &g_define_type_info, 0);
		g_once_init_leave (&photos_bmp_reader_type_id__volatile, photos_bmp_reader_type_id);
	}
	return photos_bmp_reader_type_id__volatile;
}


PhotosBmpWriter*
photos_bmp_writer_construct (GType object_type,
                             const gchar* filepath)
{
	PhotosBmpWriter* self = NULL;
#line 123 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 124 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = (PhotosBmpWriter*) photo_file_writer_construct (object_type, filepath, PHOTO_FILE_FORMAT_BMP);
#line 123 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self;
#line 1661 "BmpSupport.c"
}


PhotosBmpWriter*
photos_bmp_writer_new (const gchar* filepath)
{
#line 123 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return photos_bmp_writer_construct (PHOTOS_TYPE_BMP_WRITER, filepath);
#line 1670 "BmpSupport.c"
}


static void
photos_bmp_writer_real_write (PhotoFileWriter* base,
                              GdkPixbuf* pixbuf,
                              JpegQuality quality,
                              GError** error)
{
	PhotosBmpWriter * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	GError * _inner_error_ = NULL;
#line 127 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_WRITER, PhotosBmpWriter);
#line 127 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_if_fail (GDK_IS_PIXBUF (pixbuf));
#line 128 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 128 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = _tmp0_;
#line 128 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	gdk_pixbuf_save (pixbuf, _tmp1_, "bmp", &_inner_error_, NULL, NULL);
#line 128 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_g_free0 (_tmp1_);
#line 128 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 128 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 128 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
		return;
#line 1702 "BmpSupport.c"
	}
}


static void
photos_bmp_writer_class_init (PhotosBmpWriterClass * klass)
{
#line 122 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_writer_parent_class = g_type_class_peek_parent (klass);
#line 122 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileWriterClass *) klass)->write = (void (*) (PhotoFileWriter *, GdkPixbuf*, JpegQuality, GError**)) photos_bmp_writer_real_write;
#line 1714 "BmpSupport.c"
}


static void
photos_bmp_writer_instance_init (PhotosBmpWriter * self)
{
}


GType
photos_bmp_writer_get_type (void)
{
	static volatile gsize photos_bmp_writer_type_id__volatile = 0;
	if (g_once_init_enter (&photos_bmp_writer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosBmpWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_bmp_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosBmpWriter), 0, (GInstanceInitFunc) photos_bmp_writer_instance_init, NULL };
		GType photos_bmp_writer_type_id;
		photos_bmp_writer_type_id = g_type_register_static (TYPE_PHOTO_FILE_WRITER, "PhotosBmpWriter", &g_define_type_info, 0);
		g_once_init_leave (&photos_bmp_writer_type_id__volatile, photos_bmp_writer_type_id);
	}
	return photos_bmp_writer_type_id__volatile;
}


PhotosBmpMetadataWriter*
photos_bmp_metadata_writer_construct (GType object_type,
                                      const gchar* filepath)
{
	PhotosBmpMetadataWriter* self = NULL;
#line 133 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 134 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = (PhotosBmpMetadataWriter*) photo_file_metadata_writer_construct (object_type, filepath, PHOTO_FILE_FORMAT_BMP);
#line 133 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self;
#line 1749 "BmpSupport.c"
}


PhotosBmpMetadataWriter*
photos_bmp_metadata_writer_new (const gchar* filepath)
{
#line 133 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return photos_bmp_metadata_writer_construct (PHOTOS_TYPE_BMP_METADATA_WRITER, filepath);
#line 1758 "BmpSupport.c"
}


static void
photos_bmp_metadata_writer_real_write_metadata (PhotoFileMetadataWriter* base,
                                                PhotoMetadata* metadata,
                                                GError** error)
{
	PhotosBmpMetadataWriter * self;
#line 137 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_METADATA_WRITER, PhotosBmpMetadataWriter);
#line 137 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_if_fail (IS_PHOTO_METADATA (metadata));
#line 1772 "BmpSupport.c"
}


static void
photos_bmp_metadata_writer_class_init (PhotosBmpMetadataWriterClass * klass)
{
#line 132 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_metadata_writer_parent_class = g_type_class_peek_parent (klass);
#line 132 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileMetadataWriterClass *) klass)->write_metadata = (void (*) (PhotoFileMetadataWriter *, PhotoMetadata*, GError**)) photos_bmp_metadata_writer_real_write_metadata;
#line 1783 "BmpSupport.c"
}


static void
photos_bmp_metadata_writer_instance_init (PhotosBmpMetadataWriter * self)
{
}


GType
photos_bmp_metadata_writer_get_type (void)
{
	static volatile gsize photos_bmp_metadata_writer_type_id__volatile = 0;
	if (g_once_init_enter (&photos_bmp_metadata_writer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosBmpMetadataWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_bmp_metadata_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosBmpMetadataWriter), 0, (GInstanceInitFunc) photos_bmp_metadata_writer_instance_init, NULL };
		GType photos_bmp_metadata_writer_type_id;
		photos_bmp_metadata_writer_type_id = g_type_register_static (TYPE_PHOTO_FILE_METADATA_WRITER, "PhotosBmpMetadataWriter", &g_define_type_info, 0);
		g_once_init_leave (&photos_bmp_metadata_writer_type_id__volatile, photos_bmp_metadata_writer_type_id);
	}
	return photos_bmp_metadata_writer_type_id__volatile;
}


void
photos_bmp_file_format_driver_init (void)
{
	PhotosBmpFileFormatDriver* _tmp0_;
#line 146 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_driver_new ();
#line 146 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_photo_file_format_driver_unref0 (photos_bmp_file_format_driver_instance);
#line 146 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_driver_instance = _tmp0_;
#line 147 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_properties_init ();
#line 1819 "BmpSupport.c"
}


static gpointer
_photo_file_format_driver_ref0 (gpointer self)
{
#line 151 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self ? photo_file_format_driver_ref (self) : NULL;
#line 1828 "BmpSupport.c"
}


PhotosBmpFileFormatDriver*
photos_bmp_file_format_driver_get_instance (void)
{
	PhotosBmpFileFormatDriver* result = NULL;
	PhotosBmpFileFormatDriver* _tmp0_;
	PhotosBmpFileFormatDriver* _tmp1_;
#line 151 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_driver_instance;
#line 151 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp1_ = _photo_file_format_driver_ref0 (_tmp0_);
#line 151 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp1_;
#line 151 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1846 "BmpSupport.c"
}


static PhotoFileFormatProperties*
photos_bmp_file_format_driver_real_get_properties (PhotoFileFormatDriver* base)
{
	PhotosBmpFileFormatDriver * self;
	PhotoFileFormatProperties* result = NULL;
	PhotosBmpFileFormatProperties* _tmp0_;
#line 154 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 155 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_file_format_properties_get_instance ();
#line 155 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties);
#line 155 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1864 "BmpSupport.c"
}


static PhotoFileReader*
photos_bmp_file_format_driver_real_create_reader (PhotoFileFormatDriver* base,
                                                  const gchar* filepath)
{
	PhotosBmpFileFormatDriver * self;
	PhotoFileReader* result = NULL;
	PhotosBmpReader* _tmp0_;
#line 158 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 158 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 159 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_reader_new (filepath);
#line 159 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_READER, PhotoFileReader);
#line 159 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1885 "BmpSupport.c"
}


static gboolean
photos_bmp_file_format_driver_real_can_write_image (PhotoFileFormatDriver* base)
{
	PhotosBmpFileFormatDriver * self;
	gboolean result = FALSE;
#line 162 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 163 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = TRUE;
#line 163 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1900 "BmpSupport.c"
}


static gboolean
photos_bmp_file_format_driver_real_can_write_metadata (PhotoFileFormatDriver* base)
{
	PhotosBmpFileFormatDriver * self;
	gboolean result = FALSE;
#line 166 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 167 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = FALSE;
#line 167 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1915 "BmpSupport.c"
}


static PhotoFileWriter*
photos_bmp_file_format_driver_real_create_writer (PhotoFileFormatDriver* base,
                                                  const gchar* filepath)
{
	PhotosBmpFileFormatDriver * self;
	PhotoFileWriter* result = NULL;
	PhotosBmpWriter* _tmp0_;
#line 170 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 170 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 171 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_writer_new (filepath);
#line 171 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_WRITER, PhotoFileWriter);
#line 171 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1936 "BmpSupport.c"
}


static PhotoFileMetadataWriter*
photos_bmp_file_format_driver_real_create_metadata_writer (PhotoFileFormatDriver* base,
                                                           const gchar* filepath)
{
	PhotosBmpFileFormatDriver * self;
	PhotoFileMetadataWriter* result = NULL;
	PhotosBmpMetadataWriter* _tmp0_;
#line 174 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 174 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 175 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_metadata_writer_new (filepath);
#line 175 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriter);
#line 175 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1957 "BmpSupport.c"
}


static PhotoFileSniffer*
photos_bmp_file_format_driver_real_create_sniffer (PhotoFileFormatDriver* base,
                                                   GFile* file,
                                                   PhotoFileSnifferOptions options)
{
	PhotosBmpFileFormatDriver * self;
	PhotoFileSniffer* result = NULL;
	PhotosBmpSniffer* _tmp0_;
#line 178 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 178 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 179 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photos_bmp_sniffer_new (file, options);
#line 179 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer);
#line 179 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1979 "BmpSupport.c"
}


static PhotoMetadata*
photos_bmp_file_format_driver_real_create_metadata (PhotoFileFormatDriver* base)
{
	PhotosBmpFileFormatDriver * self;
	PhotoMetadata* result = NULL;
	PhotoMetadata* _tmp0_;
#line 182 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 183 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	_tmp0_ = photo_metadata_new ();
#line 183 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	result = _tmp0_;
#line 183 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return result;
#line 1997 "BmpSupport.c"
}


PhotosBmpFileFormatDriver*
photos_bmp_file_format_driver_construct (GType object_type)
{
	PhotosBmpFileFormatDriver* self = NULL;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = (PhotosBmpFileFormatDriver*) photo_file_format_driver_construct (object_type);
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return self;
#line 2009 "BmpSupport.c"
}


PhotosBmpFileFormatDriver*
photos_bmp_file_format_driver_new (void)
{
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	return photos_bmp_file_format_driver_construct (PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER);
#line 2018 "BmpSupport.c"
}


static void
photos_bmp_file_format_driver_class_init (PhotosBmpFileFormatDriverClass * klass)
{
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	photos_bmp_file_format_driver_parent_class = g_type_class_peek_parent (klass);
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->finalize = photos_bmp_file_format_driver_finalize;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->get_properties = (PhotoFileFormatProperties* (*) (PhotoFileFormatDriver *)) photos_bmp_file_format_driver_real_get_properties;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_reader = (PhotoFileReader* (*) (PhotoFileFormatDriver *, const gchar*)) photos_bmp_file_format_driver_real_create_reader;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->can_write_image = (gboolean (*) (PhotoFileFormatDriver *)) photos_bmp_file_format_driver_real_can_write_image;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->can_write_metadata = (gboolean (*) (PhotoFileFormatDriver *)) photos_bmp_file_format_driver_real_can_write_metadata;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_writer = (PhotoFileWriter* (*) (PhotoFileFormatDriver *, const gchar*)) photos_bmp_file_format_driver_real_create_writer;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_metadata_writer = (PhotoFileMetadataWriter* (*) (PhotoFileFormatDriver *, const gchar*)) photos_bmp_file_format_driver_real_create_metadata_writer;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_sniffer = (PhotoFileSniffer* (*) (PhotoFileFormatDriver *, GFile*, PhotoFileSnifferOptions)) photos_bmp_file_format_driver_real_create_sniffer;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_metadata = (PhotoMetadata* (*) (PhotoFileFormatDriver *)) photos_bmp_file_format_driver_real_create_metadata;
#line 2045 "BmpSupport.c"
}


static void
photos_bmp_file_format_driver_instance_init (PhotosBmpFileFormatDriver * self)
{
}


static void
photos_bmp_file_format_driver_finalize (PhotoFileFormatDriver * obj)
{
	PhotosBmpFileFormatDriver * self;
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTOS_TYPE_BMP_FILE_FORMAT_DRIVER, PhotosBmpFileFormatDriver);
#line 142 "/home/jens/Source/shotwell/src/photos/BmpSupport.vala"
	PHOTO_FILE_FORMAT_DRIVER_CLASS (photos_bmp_file_format_driver_parent_class)->finalize (obj);
#line 2063 "BmpSupport.c"
}


GType
photos_bmp_file_format_driver_get_type (void)
{
	static volatile gsize photos_bmp_file_format_driver_type_id__volatile = 0;
	if (g_once_init_enter (&photos_bmp_file_format_driver_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosBmpFileFormatDriverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_bmp_file_format_driver_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosBmpFileFormatDriver), 0, (GInstanceInitFunc) photos_bmp_file_format_driver_instance_init, NULL };
		GType photos_bmp_file_format_driver_type_id;
		photos_bmp_file_format_driver_type_id = g_type_register_static (TYPE_PHOTO_FILE_FORMAT_DRIVER, "PhotosBmpFileFormatDriver", &g_define_type_info, 0);
		g_once_init_leave (&photos_bmp_file_format_driver_type_id__volatile, photos_bmp_file_format_driver_type_id);
	}
	return photos_bmp_file_format_driver_type_id__volatile;
}



